from clinicedc_constants import NOT_AVAILABLE, PENDING

NOTE_STATUSES = (
    (PENDING, "Data is pending"),
    (NOT_AVAILABLE, "Data not available"),
)
